@@ -5,12 +5,15 @@ import os
 import sys
 import tempfile
 import time
+import uuid
 from pathlib import Path
 from typing import Any, Callable, Dict, Iterable, Optional, Tuple
+from urllib.parse import urlencode
 
 import requests
 
 from .auth import get_fireworks_account_id, get_fireworks_api_base, get_fireworks_api_key
+from .common_utils import get_user_agent
 
 
 def _map_api_host_to_app_host(api_base: str) -> str:
@@ -18,35 +21,24 @@ def _map_api_host_to_app_host(api_base: str) -> str:
         from urllib.parse import urlparse
 
         parsed = urlparse(api_base)
-        host = parsed.netloc or parsed.path
+        host = (parsed.netloc or parsed.path).lower()
+        scheme = parsed.scheme or "https"
+
+        # Explicit mappings first
         if host.startswith("dev.api.fireworks.ai"):
-            return f"{parsed.scheme or 'https'}://dev.fireworks.ai"
+            return f"{scheme}://dev.fireworks.ai"
+        if host == "staging.api.fireworks.ai" or host == "api.fireworks.ai":
+            return f"{scheme}://app.fireworks.ai"
+
+        # Generic mapping: api.<...> → app.<...>
         if host.startswith("api."):
-            return f"{parsed.scheme or 'https'}://{host.replace('api.', 'app.', 1)}"
-        return f"{parsed.scheme or 'https'}://{host}"
+            return f"{scheme}://{host.replace('api.', 'app.', 1)}"
+
+        return f"{scheme}://{host}"
     except Exception:
         return "https://app.fireworks.ai"
 
 
-def load_evaluator_trace(project_root: str, evaluator_id: str) -> Optional[Dict[str, Any]]:
-    trace_path = Path(project_root) / ".eval_protocol" / "evaluators" / f"{evaluator_id}.json"
-    if not trace_path.exists():
-        return None
-    try:
-        with open(trace_path, "r", encoding="utf-8") as f:
-            return json.load(f)
-    except Exception:
-        return None
-
-
-def save_evaluator_trace(project_root: str, evaluator_id: str, trace: Dict[str, Any]) -> None:
-    base_dir = Path(project_root) / ".eval_protocol" / "evaluators"
-    base_dir.mkdir(parents=True, exist_ok=True)
-    trace_path = base_dir / f"{evaluator_id}.json"
-    with open(trace_path, "w", encoding="utf-8") as f:
-        json.dump(trace, f, indent=2, ensure_ascii=False)
-
-
 def detect_dataset_builder(metric_dir: str) -> Optional[str]:
     """
     Best-effort scan for a dataset builder callable inside the metric directory.
@@ -149,12 +141,17 @@ def create_dataset_from_jsonl(
     display_name: Optional[str],
     jsonl_path: str,
 ) -> Tuple[str, Dict[str, Any]]:
-    headers = {"Authorization": f"Bearer {api_key}", "Content-Type": "application/json"}
+    headers = {
+        "Authorization": f"Bearer {api_key}",
+        "Content-Type": "application/json",
+        "User-Agent": get_user_agent(),
+    }
     # Count examples quickly
     example_count = 0
     with open(jsonl_path, "r", encoding="utf-8") as f:
         for _ in f:
             example_count += 1
+
     dataset_url = f"{api_base.rstrip('/')}/v1/accounts/{account_id}/datasets"
     payload = {
         "dataset": {
@@ -173,7 +170,10 @@ def create_dataset_from_jsonl(
     upload_url = f"{api_base.rstrip('/')}/v1/accounts/{account_id}/datasets/{dataset_id}:upload"
     with open(jsonl_path, "rb") as f:
         files = {"file": f}
-        up_headers = {"Authorization": f"Bearer {api_key}"}
+        up_headers = {
+            "Authorization": f"Bearer {api_key}",
+            "User-Agent": get_user_agent(),
+        }
         up_resp = requests.post(upload_url, files=files, headers=up_headers, timeout=600)
     if up_resp.status_code not in (200, 201):
         raise RuntimeError(f"Dataset upload failed: {up_resp.status_code} {up_resp.text}")
@@ -187,7 +187,20 @@ def create_reinforcement_fine_tuning_job(
     body: Dict[str, Any],
 ) -> Dict[str, Any]:
     url = f"{api_base.rstrip('/')}/v1/accounts/{account_id}/reinforcementFineTuningJobs"
-    headers = {"Authorization": f"Bearer {api_key}", "Content-Type": "application/json", "Accept": "application/json"}
+    # Move optional jobId from body to query parameter if provided
+    job_id = body.get("jobId")
+    if isinstance(job_id, str):
+        job_id = job_id.strip()
+    if job_id:
+        # Remove from body and append as query param
+        body.pop("jobId", None)
+        url = f"{url}?{urlencode({'reinforcementFineTuningJobId': job_id})}"
+    headers = {
+        "Authorization": f"Bearer {api_key}",
+        "Content-Type": "application/json",
+        "Accept": "application/json",
+        "User-Agent": get_user_agent(),
+    }
     resp = requests.post(url, json=body, headers=headers, timeout=60)
     if resp.status_code not in (200, 201):
         raise RuntimeError(f"RFT job creation failed: {resp.status_code} {resp.text}")
@@ -202,12 +215,11 @@ def build_default_dataset_id(evaluator_id: str) -> str:
 
 def build_default_output_model(evaluator_id: str) -> str:
     base = evaluator_id.lower().replace("_", "-")
-    return f"{base}-rft"
+    uuid_suffix = str(uuid.uuid4())[:4]
+    return f"{base}-rft-{uuid_suffix}"
 
 
 __all__ = [
-    "load_evaluator_trace",
-    "save_evaluator_trace",
     "detect_dataset_builder",
     "materialize_dataset_via_builder",
     "create_dataset_from_jsonl",
